@@ -50,24 +50,24 @@ void Palapeli::MainWindow::setupActions()
 	QAction * statusBarAct = KStandardAction::showStatusbar
 	(m_game->puzzleTable(), &PuzzleTableWidget::showStatusBar, actionCollection());
 	statusBarAct->setChecked(Settings::showStatusBar());
-	statusBarAct->setText(i18n("Show statusbar of puzzle table"));
+	statusBarAct->setText(i18n("Show Statusbar of Puzzle Table"));
 
 	// Back to collection.
-	QAction * goCollAct = new QAction(QIcon::fromTheme(QStringLiteral("go-previous")), i18n("Back to &collection"), this);
+	QAction * goCollAct = new QAction(QIcon::fromTheme(QStringLiteral("go-previous")), i18n("Back to &Collection"), this);
 	goCollAct->setToolTip(i18n("Go back to the collection to choose another puzzle"));
 	goCollAct->setEnabled(false); //because the collection is initially shown
 	actionCollection()->addAction(QStringLiteral("view_collection"), goCollAct);
 	connect(goCollAct, &QAction::triggered, m_game, &GamePlay::actionGoCollection);
 
 	// Create new puzzle (FIXME: action should have a custom icon).
-	QAction * createAct = new QAction(QIcon::fromTheme(QStringLiteral("tools-wizard")), i18n("Create &new puzzle..."), this);
+	QAction * createAct = new QAction(QIcon::fromTheme(QStringLiteral("tools-wizard")), i18n("Create &New Puzzle..."), this);
 	createAct->setToolTip(i18n("Create a new puzzle using an image file from your disk"));
 	actionCollection()->setDefaultShortcuts(createAct, KStandardShortcut::openNew());
 	actionCollection()->addAction(QStringLiteral("game_new"), createAct);
 	connect(createAct, &QAction::triggered, m_game, &GamePlay::actionCreate);
 
 	// Delete a puzzle.
-	QAction * deleteAct = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Delete puzzle"), this);
+	QAction * deleteAct = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Delete Puzzle"), this);
 	deleteAct->setEnabled(false); //will be enabled when something is selected
 	deleteAct->setToolTip(i18n("Delete the selected puzzle from your collection"));
 	actionCollection()->addAction(QStringLiteral("game_delete"), deleteAct);
@@ -75,13 +75,13 @@ void Palapeli::MainWindow::setupActions()
 	connect(deleteAct, &QAction::triggered, m_game, &GamePlay::actionDelete);
 
 	// Import from file...
-	QAction * importAct = new QAction(QIcon::fromTheme(QStringLiteral("document-import")), i18n("&Import from file..."), this);
+	QAction * importAct = new QAction(QIcon::fromTheme(QStringLiteral("document-import")), i18n("&Import from File..."), this);
 	importAct->setToolTip(i18n("Import a new puzzle from a file into your collection"));
 	actionCollection()->addAction(QStringLiteral("game_import"), importAct);
 	connect(importAct, &QAction::triggered, m_game, &GamePlay::actionImport);
 
 	// Export to file...
-	QAction * exportAct = new QAction(QIcon::fromTheme(QStringLiteral("document-export")), i18n("&Export to file..."), this);
+	QAction * exportAct = new QAction(QIcon::fromTheme(QStringLiteral("document-export")), i18n("&Export to File..."), this);
 	exportAct->setEnabled(false); //will be enabled when something is selected
 	exportAct->setToolTip(i18n("Export the selected puzzle from your collection into a file"));
 	actionCollection()->addAction(QStringLiteral("game_export"), exportAct);
@@ -89,7 +89,7 @@ void Palapeli::MainWindow::setupActions()
 	connect(exportAct, &QAction::triggered, m_game, &GamePlay::actionExport);
 
 	//Reshuffle and restart puzzle
-	QAction * restartPuzzleAct = new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("&Restart puzzle..."), this);
+	QAction * restartPuzzleAct = new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("&Restart Puzzle..."), this);
 	restartPuzzleAct->setToolTip(i18n("Delete the saved progress and reshuffle the pieces"));
 	restartPuzzleAct->setEnabled(false); //no puzzle in progress initially
 	actionCollection()->addAction(QStringLiteral("game_restart"), restartPuzzleAct);
@@ -97,28 +97,29 @@ void Palapeli::MainWindow::setupActions()
 	// Quit.
 	KStandardGameAction::quit (this, &QWidget::close, actionCollection());
 	// Create piece-holder.
-	QAction * createHolderAct = new QAction(i18n("&Create piece holder..."), this);
+	QAction * createHolderAct = new QAction(i18n("&Create Piece Holder..."), this);
 	createHolderAct->setToolTip(i18n("Create a temporary holder for sorting pieces"));
 	actionCollection()->setDefaultShortcut(createHolderAct, QKeySequence(Qt::Key_C));
 	actionCollection()->addAction(QStringLiteral("move_create_holder"), createHolderAct);
-	connect(createHolderAct, &QAction::triggered, m_game, QOverload<>::of(&GamePlay::createHolder));
+        connect(createHolderAct, &QAction::triggered, m_game,
+                qOverload<>(&GamePlay::createHolder));
 
-	// Delete piece-holder.
-	QAction * deleteHolderAct = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Delete piece holder"), this);
+        // Delete piece-holder.
+	QAction * deleteHolderAct = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Delete Piece Holder"), this);
 	deleteHolderAct->setToolTip(i18n("Delete a selected temporary holder when it is empty"));
 	actionCollection()->setDefaultShortcut(deleteHolderAct, QKeySequence(Qt::Key_D));
 	actionCollection()->addAction(QStringLiteral("move_delete_holder"), deleteHolderAct);
 	connect(deleteHolderAct, &QAction::triggered, m_game, &GamePlay::deleteHolder);
 
 	// Select all pieces in a piece-holder.
-	QAction * selectAllAct = new QAction(QIcon::fromTheme(QStringLiteral("edit-select-all")), i18n("&Select all in holder"), this);
+	QAction * selectAllAct = new QAction(QIcon::fromTheme(QStringLiteral("edit-select-all")), i18n("&Select All in Holder"), this);
 	selectAllAct->setToolTip(i18n("Select all pieces in a selected piece holder"));
 	actionCollection()->setDefaultShortcut(selectAllAct, QKeySequence(Qt::Key_A));
 	actionCollection()->addAction(QStringLiteral("move_select_all"), selectAllAct);
 	connect(selectAllAct, &QAction::triggered, m_game, &GamePlay::selectAll);
 
 	// Rearrange a selected piece-holder or selected pieces in any view.
-	QAction * rearrangeAct = new QAction(i18n("&Rearrange pieces"), this);
+	QAction * rearrangeAct = new QAction(i18n("&Rearrange Pieces"), this);
 	rearrangeAct->setToolTip(i18n("Rearrange all pieces in a selected piece holder or selected pieces in any window"));
 	actionCollection()->setDefaultShortcut(rearrangeAct, QKeySequence(Qt::Key_R));
 	actionCollection()->addAction(QStringLiteral("move_rearrange"), rearrangeAct);
@@ -143,7 +144,7 @@ void Palapeli::MainWindow::setupActions()
 	KStandardAction::zoomOut(m_game, &GamePlay::actionZoomOut,
 						actionCollection());
 	// Settings: enable messages that the user marked "Do not show again".
-	QAction * enableMessagesAct = new QAction(i18n("Enable all messages"), this);
+	QAction * enableMessagesAct = new QAction(i18n("Enable All Messages"), this);
 	actionCollection()->addAction(QStringLiteral("enable_messages"), enableMessagesAct);
 	connect(enableMessagesAct, &QAction::triggered, this, &MainWindow::enableMessages);
 }
